"use strict";

exports.__esModule = true;
exports.runNpmAddGdScripts = exports.runNpmCi = exports.runNpmInstall = exports.cloneOrPull = exports.getRepoName = void 0;

var _fsExtra = require("fs-extra");

var _simpleGit = _interopRequireDefault(require("simple-git"));

var _crossSpawn = _interopRequireDefault(require("cross-spawn"));

var _path = require("path");

var _os = require("os");

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const fixturePath = (0, _path.join)((0, _os.tmpdir)(), 'gd-scripts', 'fixtures');

const getRepoName = repo => {
  const rgxRepoName = /.*github.com\/.*?\/(.*?).git/;
  const match = rgxRepoName.exec(repo);

  if (!match) {
    throw new Error('Repo name not found.');
  }

  const repoName = match[1];
  return repoName;
};

exports.getRepoName = getRepoName;

const getFixtureRepoPath = repo => {
  const repoName = getRepoName(repo);
  const fixturesRepoPath = (0, _path.join)(fixturePath, repoName);
  return fixturesRepoPath;
};

const checkoutLatestTag = fixturesRepoPath => new Promise(resolve => {
  (0, _simpleGit.default)().cwd(fixturesRepoPath).checkoutLatestTag(resolve);
});

const clone = repo => new Promise(resolve => {
  (0, _simpleGit.default)().cwd(fixturePath).clone(repo, resolve);
});

const cloneOrPull = async repo => {
  const fixturesRepoPath = getFixtureRepoPath(repo);

  if (!(0, _fsExtra.pathExistsSync)(fixturesRepoPath)) {
    await clone(repo);
  }

  await checkoutLatestTag(fixturesRepoPath);
};

exports.cloneOrPull = cloneOrPull;

const runNpmInstall = repo => _crossSpawn.default.sync('npm', ['install'], {
  stdio: 'inherit',
  cwd: getFixtureRepoPath(repo)
});

exports.runNpmInstall = runNpmInstall;

const runNpmCi = repo => _crossSpawn.default.sync('npm', ['run', 'ci'], {
  stdio: 'inherit',
  cwd: getFixtureRepoPath(repo)
});

exports.runNpmCi = runNpmCi;

const runNpmAddGdScripts = repo => _crossSpawn.default.sync('npm', ['install', `file:${(0, _utils.fromRoot)('.')}`, '-D'], {
  stdio: 'inherit',
  cwd: getFixtureRepoPath(repo)
});

exports.runNpmAddGdScripts = runNpmAddGdScripts;
//# sourceMappingURL=utils.js.map